# Installation

~~`pip install HGQ`, and you are good to go.~~ (v0.2 is not released on PyPI yet. The current version on PyPI is v0.1.)

`pip install git+https://github.com/calad0i/HGQ` to install the latest version from github.

```{warning}
This framework requires an **unmerged** [PR](https://github.com/fastmachinelearning/hls4ml/pull/914) of hls4ml. Please install it by running `pip install "git+https://github.com/calad0i/hls4ml@HGQ-integration"`. Or, conversion will fail with unsupported layer error.
```

```{note}
The current varsion requires an **unmerged** version of hls4ml. Please install it by running `pip install git+https://github.com/calad0i/hls4ml`.
```

```{warning}
HGQ requires `python3.10/3.11` and `tensorflow==2.13`. Please make sure that you have the correct version of python and tensorflow installed.
```
